==> jupyterlab-code-snippets-2.1.0.tgz: package/lib/CodeSnippetMessage.js <==
// Copyright (c) 2020, jupytercalpoly
// Distributed under the terms of the BSD-3 Clause License.
// import { WidgetTracker, ReactWidget } from '@jupyterlab/apputils';
import { Dialog } from '@jupyterlab/apputils';
import { Widget } from '@lumino/widgets';
import checkSVGstr from '../style/icon/jupyter_checkmark.svg';
/**
 * The class name for message
 */
// const CONFIRM_CLASS = 'jp-codeSnippet-confirm';
const CONFIRM_CONTENT = 'jp-codeSnippet-Message-content';
const CONFIRM_BODY = 'jp-codeSnippet-Message-body';
const CODE_SNIPPET_CONFIRM_TEXT = 'jp-codeSnippet-confirm-text';
/**
 * Create and show a dialog.
 *
 * @param options - The dialog setup options.
 *
 * @returns A promise that resolves with whether the dialog was accepted.
 */
export function showMessage(type) {
    const confirmMessage = new CodeSnippetMessage({
        body: new MessageHandler(type),
        buttons: [],
    });
    return confirmMessage.launch();
}
/**
 * A widget used to show message.
 */
export class CodeSnippetMessage extends Dialog {
    constructor(options = {}) {
        super(options);
        this.children().next().addClass(CONFIRM_CONTENT);
    }
    onAfterAttach(msg) {
        const node = this.node;
        node.addEventListener('click', this, true);
        document.addEventListener('keydown', this, false);
    }
    /**
     *  A message handler invoked on an `'after-detach'` message.
     */
    onAfterDetach(msg) {
        const node = this.node;
        node.removeEventListener('click', this, true);
        document.removeEventListener('keydown', this, false);
    }
    handleEvent(event) {
        switch (event.type) {
            case 'keydown':
                this._evtKeydown(event);
                break;
            case 'click':
                this._evtClick(event);
                break;
        }
    }
    _evtKeydown(event) {
        // Check for escape key
        switch (event.key) {
            case 'Escape':
                event.stopPropagation();
                event.preventDefault();
                this.reject();
                break;
        }
    }
}
class MessageHandler extends Widget {
    constructor(type) {
        super({ node: Private.createMessageNode(type) });
        this.addClass(CONFIRM_BODY);
    }
}
/**
 * The namespace for module private data.
 */
var Private;
(function (Private) {
    // create a confirm message when new snippet is created successfully
    function createMessageNode(type) {
        const body = document.createElement('div');
        body.innerHTML = checkSVGstr;
        const messageContainer = document.createElement('div');
        messageContainer.className = CODE_SNIPPET_CONFIRM_TEXT;
        const message = document.createElement('text');
        if (type === 'confirm') {
            message.textContent = 'Saved as Snippet!';
        }
        else if (type === 'copy') {
            message.textContent = 'Saved to Clipboard!';
        }
        else if (type === 'download') {
            message.textContent = 'Downloaded the Snippet!';
        }
        messageContainer.appendChild(message);
        body.append(messageContainer);
        return body;
    }
    Private.createMessageNode = createMessageNode;
})(Private || (Private = {}));

==> jupyterlab-code-snippets-2.2.0.tgz: package/lib/CodeSnippetMessage.js <==
// Copyright (c) 2020, jupytercalpoly
// Distributed under the terms of the BSD-3 Clause License.
// import { WidgetTracker, ReactWidget } from '@jupyterlab/apputils';
import { Dialog } from '@jupyterlab/apputils';
import { Widget } from '@lumino/widgets';
import checkSVGstr from '../style/icon/jupyter_checkmark.svg';
/**
 * The class name for message
 */
// const CONFIRM_CLASS = 'jp-codeSnippet-confirm';
const CONFIRM_CONTENT = 'jp-codeSnippet-Message-content';
const CONFIRM_BODY = 'jp-codeSnippet-Message-body';
const CODE_SNIPPET_CONFIRM_TEXT = 'jp-codeSnippet-confirm-text';
/**
 * Create and show a dialog.
 *
 * @param options - The dialog setup options.
 *
 * @returns A promise that resolves with whether the dialog was accepted.
 */
export function showMessage(type) {
    const confirmMessage = new CodeSnippetMessage({
        body: new MessageHandler(type),
        buttons: [],
    });
    return confirmMessage.launch();
}
/**
 * A widget used to show message.
 */
export class CodeSnippetMessage extends Dialog {
    constructor(options = {}) {
        super(options);
        this.children().next().addClass(CONFIRM_CONTENT);
    }
    onAfterAttach(msg) {
        const node = this.node;
        node.addEventListener('click', this, true);
        document.addEventListener('keydown', this, false);
    }
    /**
     *  A message handler invoked on an `'after-detach'` message.
     */
    onAfterDetach(msg) {
        const node = this.node;
        node.removeEventListener('click', this, true);
        document.removeEventListener('keydown', this, false);
    }
    handleEvent(event) {
        switch (event.type) {
            case 'keydown':
                this._evtKeydown(event);
                break;
            case 'click':
                this._evtClick(event);
                break;
        }
    }
    _evtKeydown(event) {
        // Check for escape key
        switch (event.key) {
            case 'Escape':
                event.stopPropagation();
                event.preventDefault();
                this.reject();
                break;
        }
    }
}
class MessageHandler extends Widget {
    constructor(type) {
        super({ node: Private.createMessageNode(type) });
        this.addClass(CONFIRM_BODY);
    }
}
/**
 * The namespace for module private data.
 */
var Private;
(function (Private) {
    // create a confirm message when new snippet is created successfully
    function createMessageNode(type) {
        const body = document.createElement('div');
        body.innerHTML = checkSVGstr;
        const messageContainer = document.createElement('div');
        messageContainer.className = CODE_SNIPPET_CONFIRM_TEXT;
        const message = document.createElement('text');
        if (type === 'confirm') {
            message.textContent = 'Saved as Snippet!';
        }
        else if (type === 'copy') {
            message.textContent = 'Saved to Clipboard!';
        }
        else if (type === 'export') {
            message.textContent = 'Exported the Snippet!';
        }
        messageContainer.appendChild(message);
        body.append(messageContainer);
        return body;
    }
    Private.createMessageNode = createMessageNode;
})(Private || (Private = {}));
